celest_test library

Classes

CelestAuthTester
A helper class for running integration tests with Celest Auth.
CelestTester
A helper class for running integration tests with Celest.

Typedefs

Otp = ({String code, String to})
An OTP code sent by the server.